==> mythdvd_0.16.orig.tar.gz: mythdvd-0.16/i18n/mythdvd_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>DVDRipBox</name>
    <message>
        <source>Your connection to the Myth Transcoding Daemon has gone away. This is not a good thing.</source>
        <translation>Die Verbindung zum Myth Transcoding Daemon wurde unterbrochen. Das ist nicht gut.</translation>
    </message>
    <message>
        <source>Cannot connect to your Myth Transcoding Daemon. You can try hitting any number key to start it. If you still see this message, then something is really wrong.</source>
        <translation>Kann nicht zum Myth Transcoding Daemon verbinden. Drücken Sie eine Zifferntaste um ihn zu starten. Sollte diese Meldung wieder erscheinen, dann ist etwas wirklich nicht in Ordnung.</translation>
    </message>
    <message>
        <source>Attempting to connect to your mtd said host not found. This is unrecoverably bad. </source>
        <translation>Habe den Fehler &apos;Rechner nicht gefunden&apos; beim Verbinden zum MTD erhalten. Ich kann nicht weitermachen.</translation>
    </message>
    <message>
        <source>Socket communication errors. This is unrecoverably bad. </source>
        <translation>Socket Fehler. Ich kann nicht weitermachen.</translation>
    </message>
    <message>
        <source>Something is wrong, but I don&apos;t know what.</source>
        <translation>Etwas stimmt nicht, aber ich weiß nicht genau was.</translation>
    </message>
    <message>
        <source>Job %1 of %2</source>
        <translation>Auftrag %1 von %2</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a DVD.</source>
        <translation>Es gibt nichts zu tun. Drücken Sie &apos;0&apos; um eine DVD zu rippen.</translation>
    </message>
    <message>
        <source>No Jobs. Checking and/or waiting for DVD.</source>
        <translation>Keine Aufträge. Warte bis eine DVD eingelegt wird.</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a disc if you like.</source>
        <translation>Es gibt nichts zu tun. Drücken Sie &apos;0&apos; um eine DVD zu rippen.</translation>
    </message>
    <message>
        <source>Cancelling ...</source>
        <translation>Breche ab...</translation>
    </message>
    <message>
        <source>0 New Rip</source>
        <translation>&apos;0&apos; Neuer Rip</translation>
    </message>
    <message>
        <source>9 Cancel Job</source>
        <translation>&apos;9&apos; Auftrag abbrechen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>

You have no VCD Player command defined.</source>
        <translation>Sie haben keinen VCD Abspielbefehl eingerichtet.</translation>
    </message>
    <message>
        <source>OK, I&apos;ll go run Setup</source>
        <translation>Gut, Ich werde Setup starten</translation>
    </message>
    <message>
        <source>

You have no VCD Device defined.</source>
        <translation>Sie haben kein VCD Gerät eingerichtet.</translation>
    </message>
    <message>
        <source>

You have no DVD Player command defined.</source>
        <translation>Sie haben keinen DVD Abspielbefehl eingerichtet.</translation>
    </message>
    <message>
        <source>

You have no DVD Device defined.</source>
        <translation>Sie haben kein DVD Gerät eingerichtet.</translation>
    </message>
    <message>
        <source>Location of VCD device</source>
        <translation>Pfad zum VCD Gerät</translation>
    </message>
    <message>
        <source>This device must exist, and the user running MythDVD needs to have read permission on the device.</source>
        <translation>Dieses Gerät muß existieren und MythDVD die Leserechte dafür besitzen.</translation>
    </message>
    <message>
        <source>Location of DVD device</source>
        <translation>Pfad zum DVD Gerät</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Allgemeines</translation>
    </message>
    <message>
        <source>DVD Player Command</source>
        <translation>DVD Spieler Befehlszeile</translation>
    </message>
    <message>
        <source>This can be any command to launch a DVD player (e.g. MPlayer, ogle, etc.). If present, %d will be substituted for the DVD device (e.g. /dev/dvd).</source>
        <translation>Dieser Befehl sollte den DVD Spieler starten (z.B. mplayer, ogle usw.). &apos;%d&apos; wird dabei durch das DVD-Gerät ersetzt (z.B. /dev/dvd).</translation>
    </message>
    <message>
        <source>VCD Player Command</source>
        <translation>VCD Spieler Befehlszeile</translation>
    </message>
    <message>
        <source>This can be any command to launch a VCD player (e.g. MPlayer, xine, etc.). If present, %d will be substituted for the VCD device (e.g. /dev/cdrom).</source>
        <translation>Dieser Befehl sollte den VCD Spieler starten (z.B. mplayer, xine usw.). &apos;%d&apos; wird dabei durch das VCD-Gerät ersetzt (z.B. /dev/cdrom).</translation>
    </message>
    <message>
        <source>DVD Player Settings</source>
        <translation>DVD Spieler Einstellungen</translation>
    </message>
    <message>
        <source>VCD Player Settings</source>
        <translation>VCD Spieler Einstellungen</translation>
    </message>
    <message>
        <source>Directory to hold temporary files</source>
        <translation>Temp. Verzeichnis</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythDVD needs to have write permission to the directory.</source>
        <translation>Verzeichnis für temporäre Dateien. Es muß bereits existieren und MythDVD Schreibrechte dafür besitzen.</translation>
    </message>
    <message>
        <source>Title Playing Command</source>
        <translation>Titel Abspielbefehl</translation>
    </message>
    <message>
        <source>This is a command used to preview a given title on a DVD. If present %t will be set to the title, %d for device, %a for audio track, %c for audio channels.</source>
        <translation>Dieser Befehl startet die Vorschau eines Titels einer DVD. &apos;%t&apos; wird durch den Titel, &apos;%d&apos; durch das Gerät, &apos;%a&apos; durch die Audiospur und &apos;%c&apos; durch die Anzahl der Audiokanäle ersetzt.</translation>
    </message>
    <message>
        <source>Subtitle arguments:</source>
        <translation>Argumente für Untertitel:</translation>
    </message>
    <message>
        <source>If you choose any subtitles for ripping, this command is added to the end of the Title Play Command to allow previewing of subtitles. If  present %s will be set to the subtitle track. </source>
        <translation>Wenn Sie einen Untertitel für die Umwandlung ausgewählt haben, wird dieser Befehl dem Titel-Abspielbefehl hinzugefügt, um die Vorschau von Untertiteln zu erlauben. &apos;%s&apos; wird durch die Untertitelspur ersetzt.</translation>
    </message>
    <message>
        <source>Base transcode command</source>
        <translation>Pfad zu &apos;transcode&apos;</translation>
    </message>
    <message>
        <source>This is the base (without arguments) command to run transcode on your system.</source>
        <translation>vollständiger Pfad und Dateiname zu &apos;transcode&apos; (z.B. /usr/bin/transcode).</translation>
    </message>
    <message>
        <source>MTD port number</source>
        <translation>MTD Portnummer</translation>
    </message>
    <message>
        <source>The port number that should be used for communicating with the MTD (Myth Transcoding Daemon)</source>
        <translation>Die Portnummer für die Kommunikation mit dem MTD (Myth Transcoding Daemon)</translation>
    </message>
    <message>
        <source>MTD logs to terminal window</source>
        <translation>Im Terminalfenster loggen</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will log to the window it is started from. Otherwise, it will write to a file called  mtd.log in the top level ripping directory.</source>
        <translation>Falls gesetzt, so protokolliert der MTD im Ursprungsfenster. Ansonsten werden alle Meldungen in die Datei &apos;mtd.log&apos; im obersten Rippingverzeichnis geschrieben.</translation>
    </message>
    <message>
        <source>Transcode AC3 Audio</source>
        <translation>AC3 Audio umwandeln</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will, by default, preserve AC3 (Dolby Digital) audio in transcoded files. </source>
        <translation>Falls gesetzt, bleibt AC3 Audio (Dolby Digital) in umgewandelten Dateien erhalten.</translation>
    </message>
    <message>
        <source>Use xvid rather than divx</source>
        <translation>Bevorzuge &apos;xvid&apos;</translation>
    </message>
    <message>
        <source>If set, mythdvd will use the (open, free) xvid codec rather than divx whenever possible.</source>
        <translation>Falls gesetzt, so wird der Opensource Kodierer &apos;xvid&apos; verwendet. Ansonsten der &apos;divx&apos; Kodierer.</translation>
    </message>
    <message>
        <source>Nice level for MTD</source>
        <translation>&apos;Nice&apos; Wert für den MTD</translation>
    </message>
    <message>
        <source>This determines the priority of the Myth Transcoding Daemon. Higher numbers mean lower priority (more CPU to other tasks).</source>
        <translation>Dies bestimmt die Priorität des MTD. Größere Werte bedeuten eine geringere Priorität (mehr Rechenzeit für andere Aufgaben).</translation>
    </message>
    <message>
        <source>Ripped video segments</source>
        <translation>max. Segmentgröße</translation>
    </message>
    <message>
        <source>If set to something other than 0, ripped video titles will be broken up into files of this size (in MB). Applies to both perfect quality recordings and intermediate files used for transcoding.</source>
        <translation>Falls ungleich Null, so werden gerippte Videotitel in mehrere Dateien dieser Größe (in MB) aufgeteilt. Gilt für Perfekte Qualität und für temporäre Dateien während der Umwandlung.</translation>
    </message>
    <message>
        <source>DVD Ripper Settings</source>
        <translation>DVD Ripper Einstellungen</translation>
    </message>
    <message>
        <source>MTD Settings</source>
        <translation>MTD Einstellungen</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <source>Waiting For Access to DVD</source>
        <translation>Warte auf Zugriffserlaubnis auf die DVD</translation>
    </message>
    <message>
        <source>Ripping to file ~</source>
        <translation>Rippe in Datei ~</translation>
    </message>
    <message>
        <source>Perfect DVD Rip of %1</source>
        <translation>Perfekter DVD Rip von %1</translation>
    </message>
    <message>
        <source>Transcode of %1</source>
        <translation>Umwandlung von %1</translation>
    </message>
    <message>
        <source>Waiting for Permission to Start Transcoding</source>
        <translation>Warte auf Freigabe um die Umwandlung zu starten</translation>
    </message>
    <message>
        <source>Transcoding Pass 1 of 2 ~</source>
        <translation>Umwandlung Durchlauf 1 von 2 ~</translation>
    </message>
    <message>
        <source>Transcoding Pass 2 of 2 ~</source>
        <translation>Umwandlung Durchlauf 2 von 2 ~</translation>
    </message>
    <message>
        <source>Transcoding ~</source>
        <translation>Umwandlung ~</translation>
    </message>
    <message>
        <source>Transcode is thinking </source>
        <translation>&apos;transcode&apos; denkt nach</translation>
    </message>
    <message>
        <source>Simultaneous Transcode Jobs</source>
        <translation>Anzahl paralleler Aufträge</translation>
    </message>
    <message>
        <source>This determines the number of simultaneous transcode jobs. If set at 1 (the default), there will only be one active job at a time.</source>
        <translation>Bestimmt die Anzahl paralleler Umwandlungsaufträge. Bei &apos;1&apos; (Vorgabe) wird jeweils nur ein Auftrag gestartet.</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Rip/Transcode</source>
        <translation>Rippen/Umwandeln</translation>
    </message>
    <message>
        <source>Job 1 of 1</source>
        <translation>Auftrag 1 von 1</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Länge:</translation>
    </message>
    <message>
        <source>Select:</source>
        <translation>Wähle:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Qualität:</translation>
    </message>
    <message>
        <source>Audio Track:</source>
        <translation>Audiospur:</translation>
    </message>
    <message>
        <source>AC3 Audio:</source>
        <translation>AC3 Audio:</translation>
    </message>
    <message>
        <source>Subtitles:</source>
        <translation>Untertitel:</translation>
    </message>
    <message>
        <source>View:</source>
        <translation>Ansehen:</translation>
    </message>
    <message>
        <source>Title 1 of 1</source>
        <translation>Titel 1 von 1</translation>
    </message>
    <message>
        <source>0:00:00</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TitleDialog</name>
    <message>
        <source>Unkown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <source>%1 - Title %2</source>
        <translation>%1 - Titel %2</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfekt</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nichts</translation>
    </message>
    <message>
        <source>Title %1 of %2</source>
        <translation>Titel %1 von %2</translation>
    </message>
    <message>
        <source>0 Process Selected Title</source>
        <translation>0 Verarbeite gewählten Titel</translation>
    </message>
    <message>
        <source>0 Process Selected Titles</source>
        <translation>0 Verarbeite gewählte Titel</translation>
    </message>
</context>
</TS>

==> mythdvd_0.17.orig.tar.gz: mythdvd-0.17/i18n/mythdvd_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>DVDRipBox</name>
    <message>
        <source>Your connection to the Myth Transcoding Daemon has gone away. This is not a good thing.</source>
        <translation>Die Verbindung zum Myth Transcoding Daemon wurde unterbrochen. Das ist nicht gut.</translation>
    </message>
    <message>
        <source>Cannot connect to your Myth Transcoding Daemon. You can try hitting any number key to start it. If you still see this message, then something is really wrong.</source>
        <translation>Kann nicht zum Myth Transcoding Daemon verbinden. Drücken Sie eine Zifferntaste um ihn zu starten. Sollte diese Meldung wieder erscheinen, dann ist wirklich etwas nicht in Ordnung.</translation>
    </message>
    <message>
        <source>Attempting to connect to your mtd said host not found. This is unrecoverably bad. </source>
        <translation>Habe den Fehler &apos;Rechner nicht gefunden&apos; beim Verbinden zum MTD erhalten. Ich kann nicht weitermachen.</translation>
    </message>
    <message>
        <source>Socket communication errors. This is unrecoverably bad. </source>
        <translation>Socket Fehler. Ich kann nicht weitermachen.</translation>
    </message>
    <message>
        <source>Something is wrong, but I don&apos;t know what.</source>
        <translation>Etwas stimmt nicht, aber ich weiß nicht genau was.</translation>
    </message>
    <message>
        <source>Job %1 of %2</source>
        <translation>Auftrag %1 von %2</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a DVD.</source>
        <translation>Es gibt nichts zu tun. Drücken Sie &apos;0&apos; um eine DVD zu importieren.</translation>
    </message>
    <message>
        <source>No Jobs. Checking and/or waiting for DVD.</source>
        <translation>Keine Aufträge. Warte bis eine DVD eingelegt wird.</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a disc if you like.</source>
        <translation>Es gibt nichts zu tun. Drücken Sie &apos;0&apos; um eine CD zu importieren.</translation>
    </message>
    <message>
        <source>Cancelling ...</source>
        <translation>Breche ab...</translation>
    </message>
    <message>
        <source>0 New Rip</source>
        <translation>&apos;0&apos; Neuer Import</translation>
    </message>
    <message>
        <source>9 Cancel Job</source>
        <translation>&apos;9&apos; Auftrag abbrechen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>

You have no VCD Player command defined.</source>
        <translation>

Sie haben keinen Befehl zum Abspielen von VCDs definiert.</translation>
    </message>
    <message>
        <source>OK, I&apos;ll go run Setup</source>
        <translation>Gut, Ich werde Setup starten</translation>
    </message>
    <message>
        <source>

You have no VCD Device defined.</source>
        <translation>Sie haben kein VCD Gerät eingerichtet.</translation>
    </message>
    <message>
        <source>

You have no DVD Player command defined.</source>
        <translation>

Sie haben keinen Befehl zum Abspielen von DVDs definiert.</translation>
    </message>
    <message>
        <source>

You have no DVD Device defined.</source>
        <translation>Sie haben kein DVD Gerät eingerichtet.</translation>
    </message>
    <message>
        <source>Location of VCD device</source>
        <translation>Pfad zum VCD Gerät</translation>
    </message>
    <message>
        <source>This device must exist, and the user running MythDVD needs to have read permission on the device.</source>
        <translation>Dieses Gerät muß existieren und MythDVD die Leserechte dafür besitzen.</translation>
    </message>
    <message>
        <source>Location of DVD device</source>
        <translation>Pfad zum DVD Gerät</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Grundeinstellungen</translation>
    </message>
    <message>
        <source>DVD Player Command</source>
        <translation>DVD Abspielbefehl</translation>
    </message>
    <message>
        <source>This can be any command to launch a DVD player (e.g. MPlayer, ogle, etc.). If present, %d will be substituted for the DVD device (e.g. /dev/dvd).</source>
        <translation>Dieser Befehl sollte den DVD Spieler starten (z.B. mplayer, ogle usw.). &apos;%d&apos; wird dabei durch das DVD-Gerät ersetzt (z.B. /dev/dvd).</translation>
    </message>
    <message>
        <source>VCD Player Command</source>
        <translation>VCD Abspielbefehl</translation>
    </message>
    <message>
        <source>This can be any command to launch a VCD player (e.g. MPlayer, xine, etc.). If present, %d will be substituted for the VCD device (e.g. /dev/cdrom).</source>
        <translation>Dieser Befehl sollte den VCD Spieler starten (z.B. mplayer, xine usw.). &apos;%d&apos; wird dabei durch das VCD-Gerät ersetzt (z.B. /dev/cdrom).</translation>
    </message>
    <message>
        <source>DVD Player Settings</source>
        <translation>DVD Wiedergabe</translation>
    </message>
    <message>
        <source>VCD Player Settings</source>
        <translation>VCD Wiedergabe</translation>
    </message>
    <message>
        <source>Directory to hold temporary files</source>
        <translation>Verzeichnis für temp. Dateien</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythDVD needs to have write permission to the directory.</source>
        <translation>Verzeichnis für temporäre Dateien. Es muß bereits existieren und MythDVD Schreibrechte dafür besitzen.</translation>
    </message>
    <message>
        <source>Title Playing Command</source>
        <translation>Titel Abspielbefehl</translation>
    </message>
    <message>
        <source>This is a command used to preview a given title on a DVD. If present %t will be set to the title, %d for device, %a for audio track, %c for audio channels.</source>
        <translation>Dieser Befehl startet die Vorschau eines Titels einer DVD. &apos;%t&apos; wird durch den Titel, &apos;%d&apos; durch das Gerät, &apos;%a&apos; durch die Audiospur und &apos;%c&apos; durch die Anzahl der Audiokanäle ersetzt.</translation>
    </message>
    <message>
        <source>Subtitle arguments:</source>
        <translation>Argumente für Untertitel:</translation>
    </message>
    <message>
        <source>If you choose any subtitles for ripping, this command is added to the end of the Title Play Command to allow previewing of subtitles. If  present %s will be set to the subtitle track. </source>
        <translation>Wenn Sie einen Untertitel für die Umwandlung ausgewählt haben, wird dieser Befehl dem Titel-Abspielbefehl hinzugefügt, um die Vorschau von Untertiteln zu erlauben. &apos;%s&apos; wird durch die Untertitelspur ersetzt.</translation>
    </message>
    <message>
        <source>Base transcode command</source>
        <translation>Pfad zu &apos;transcode&apos;</translation>
    </message>
    <message>
        <source>This is the base (without arguments) command to run transcode on your system.</source>
        <translation>Vollständiger Pfad und Dateiname zu &apos;transcode&apos; (z.B. /usr/bin/transcode).</translation>
    </message>
    <message>
        <source>MTD port number</source>
        <translation>Portnummer des MTD</translation>
    </message>
    <message>
        <source>The port number that should be used for communicating with the MTD (Myth Transcoding Daemon)</source>
        <translation>Die Portnummer für die Kommunikation mit dem MTD.</translation>
    </message>
    <message>
        <source>MTD logs to terminal window</source>
        <translation>Im Terminalfenster loggen</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will log to the window it is started from. Otherwise, it will write to a file called  mtd.log in the top level ripping directory.</source>
        <translation>Falls gesetzt, protokolliert der MTD im Terminalfenster in dem er gestartet wurde. Ansonsten werden alle Meldungen in die Datei &apos;mtd.log&apos; im obersten Importverzeichnis geschrieben.</translation>
    </message>
    <message>
        <source>Transcode AC3 Audio</source>
        <translation>AC3 Audio erhalten</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will, by default, preserve AC3 (Dolby Digital) audio in transcoded files. </source>
        <translation>Falls gesetzt, bleibt AC3 Audio (Dolby Digital) in umgewandelten Dateien erhalten.</translation>
    </message>
    <message>
        <source>Use xvid rather than divx</source>
        <translation>Bevorzuge &apos;xvid&apos;</translation>
    </message>
    <message>
        <source>If set, mythdvd will use the (open, free) xvid codec rather than divx whenever possible.</source>
        <translation>Falls gesetzt, so wird der Opensource &apos;xvid&apos; Videocodec verwendet. Ansonsten der &apos;divx&apos; Videocodec.</translation>
    </message>
    <message>
        <source>Nice level for MTD</source>
        <translation>Priorität des MTD</translation>
    </message>
    <message>
        <source>This determines the priority of the Myth Transcoding Daemon. Higher numbers mean lower priority (more CPU to other tasks).</source>
        <translation>Dies bestimmt die Priorität des MTD. Größere Werte bedeuten eine geringere Priorität (mehr Rechenzeit für andere Aufgaben).</translation>
    </message>
    <message>
        <source>Ripped video segments</source>
        <translation>max. Segmentgröße</translation>
    </message>
    <message>
        <source>If set to something other than 0, ripped video titles will be broken up into files of this size (in MB). Applies to both perfect quality recordings and intermediate files used for transcoding.</source>
        <translation>Falls ungleich Null, so werden importierte Videotitel in mehrere Dateien dieser Größe (in MB) aufgeteilt. Gilt für Perfekte Qualität und für temporäre Dateien während der Umwandlung.</translation>
    </message>
    <message>
        <source>DVD Ripper Settings</source>
        <translation>DVD Import</translation>
    </message>
    <message>
        <source>MTD Settings</source>
        <translation>MTD (Myth Transcoding Daemon)</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <source>Waiting For Access to DVD</source>
        <translation>Warte auf Zugriffserlaubnis auf die DVD</translation>
    </message>
    <message>
        <source>Ripping to file ~</source>
        <translation>Importiere in Datei ~</translation>
    </message>
    <message>
        <source>Perfect DVD Rip of %1</source>
        <translation>Perfekter DVD Import von %1</translation>
    </message>
    <message>
        <source>Transcode of %1</source>
        <translation>Umwandlung von %1</translation>
    </message>
    <message>
        <source>Waiting for Permission to Start Transcoding</source>
        <translation>Warte auf Freigabe um die Umwandlung zu starten</translation>
    </message>
    <message>
        <source>Transcoding Pass 1 of 2 ~</source>
        <translation>Umwandlung Durchlauf 1 von 2 ~</translation>
    </message>
    <message>
        <source>Transcoding Pass 2 of 2 ~</source>
        <translation>Umwandlung Durchlauf 2 von 2 ~</translation>
    </message>
    <message>
        <source>Transcoding ~</source>
        <translation>Umwandlung ~</translation>
    </message>
    <message>
        <source>Transcode is thinking </source>
        <translation>Transcode denkt nach </translation>
    </message>
    <message>
        <source>Simultaneous Transcode Jobs</source>
        <translation>Anzahl paralleler Aufträge</translation>
    </message>
    <message>
        <source>This determines the number of simultaneous transcode jobs. If set at 1 (the default), there will only be one active job at a time.</source>
        <translation>Bestimmt die Anzahl paralleler Umwandlungsaufträge. Bei &apos;1&apos; (Vorgabe) wird jeweils nur ein Auftrag gestartet.</translation>
    </message>
    <message>
        <source>On DVD insertion</source>
        <translation>Beim DVD einlegen</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation>Nichts tun</translation>
    </message>
    <message>
        <source>Play DVD</source>
        <translation>DVD abspielen</translation>
    </message>
    <message>
        <source>Rip DVD</source>
        <translation>DVD importieren</translation>
    </message>
    <message>
        <source>Media Monitoring should be turned on to allow this feature (Setup -&gt; General -&gt; CD/DVD Monitor</source>
        <translation>Für diese Funktion muß die Überwachung der CD/DVD Laufwerke eingeschalten sein (Konfiguration -&gt; Grundeinstellungen -&gt; Allgemeines, Option &apos;CD/DVD Lw beobachten&apos;)</translation>
    </message>
    <message>
        <source>Display mythdvd menu</source>
        <translation>MythDVD Menü anzeigen</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Rip/Transcode</source>
        <translation>Import/Umwandeln</translation>
    </message>
    <message>
        <source>Job 1 of 1</source>
        <translation>Auftrag 1 von 1</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Länge:</translation>
    </message>
    <message>
        <source>Select:</source>
        <translation>Wähle:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Qualität:</translation>
    </message>
    <message>
        <source>Audio Track:</source>
        <translation>Audiospur:</translation>
    </message>
    <message>
        <source>AC3 Audio:</source>
        <translation>AC3 Audio:</translation>
    </message>
    <message>
        <source>Subtitles:</source>
        <translation>Untertitel:</translation>
    </message>
    <message>
        <source>View:</source>
        <translation>Ansehen:</translation>
    </message>
    <message>
        <source>Title 1 of 1</source>
        <translation>Titel 1 von 1</translation>
    </message>
    <message>
        <source>0:00:00</source>
        <translation>0:00:00</translation>
    </message>
</context>
<context>
    <name>TitleDialog</name>
    <message>
        <source>Unkown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <source>%1 - Title %2</source>
        <translation>%1 - Titel %2</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfekt</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nichts</translation>
    </message>
    <message>
        <source>Title %1 of %2</source>
        <translation>Titel %1 von %2</translation>
    </message>
    <message>
        <source>0 Process Selected Title</source>
        <translation>0 Verarbeite gewählten Titel</translation>
    </message>
    <message>
        <source>0 Process Selected Titles</source>
        <translation>0 Verarbeite gewählte Titel</translation>
    </message>
</context>
</TS>
